@@ -1,4 +1,4 @@
-use crate::types::{Bytes, H256, U256};
+use crate::types::{Address, Bytes, H256, U256};
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Default, Clone, PartialEq, Deserialize, Serialize)]
@@ -9,7 +9,9 @@ pub struct StorageProof {
 }
 
 #[derive(Debug, Default, Clone, PartialEq, Deserialize, Serialize)]
+#[serde(rename_all = "camelCase")]
 pub struct EIP1186ProofResponse {
+    address: Address,
     balance: U256,
     code_hash: H256,
     nonce: U256,
@@ -17,3 +19,14 @@ pub struct EIP1186ProofResponse {
     account_proof: Vec<Bytes>,
     storage_proof: Vec<StorageProof>,
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn can_deserialize_proof() {
+        serde_json::from_str::<EIP1186ProofResponse>(include_str!("../../testdata/proof.json"))
+            .unwrap();
+    }
+}
